@@ -4,25 +4,26 @@ use strict;
 
 use base 'POD2::Base';
 
-our $VERSION = '5.12.3.07';
+our $VERSION = '5.14.1.01';
 
 sub search_perlfunc_re {
     return 'Lista de funciones de Perl en orden alfabtico';
 }
 
 sub pod_info {{
-    perl        => '5.12.3',
-    perlbook    => '5.12.3',
-    perlfaq1    => '5.12.3',
-    perlintro   => '5.12.3',
-    perlunitut  => '5.12.3',
-    'README.freebsd'  => '5.12.3',
-    'README.openbsd'  => '5.12.3',
-    # perlcheat  => '5.12.3',
-    # perldata   => '5.12.3',
-    # perlfunc   => '5.12.3',
-    # perlstyle  => '5.12.3',
-    # perlsyn    => '5.12.3',
+    perl        => '5.14.1',
+    perlbook    => '5.14.1',
+    #perldata    => '5.14.1',
+    perlfaq1    => '5.14.1',
+    perlintro   => '5.14.1',
+    perlunitut  => '5.14.1',
+    perlutil    => '5.14.1',
+    'README.freebsd'  => '5.14.1',
+    'README.openbsd'  => '5.14.1',
+    # perlcheat  => '5.14.1',
+    # perlfunc   => '5.14.1',
+    # perlstyle  => '5.14.1',
+    # perlsyn    => '5.14.1',
 }};
 
 sub print_pod {
@@ -154,8 +155,8 @@ mecanismo sencillo, similar a un complemento.
 El paquete de idioma C<POD2::E<lt>idiomaE<gt>> debe exportar
 C<search_perlfunc_re> para devolver una traduccin de la cadena mencionada en
 el prrafo anterior. Esta cadena se usar para omitir la introduccin de
-F<perlfunc.pod>. Si C<POD2::E<lt>idiomaE<gt>-E<gt>search_perlfunc_re> genera
-un error (o no existe), se restablece el comportamiento predeterminado. Este
+F<perlfunc.pod>. Si C<POD2::E<lt>idiomaE<gt>-E<gt>search_perlfunc_re> genera un
+error (o no existe), se restablece el comportamiento predeterminado. Este
 mecanismo permite agregar traducciones de C<POD2::*> adicionales sin necesidad
 de aplicar cada vez la revisin de F<Pod/Perldoc.pm>.
 
